==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/ru/download20.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2012 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<h3 class="top">Цифровая подпись</h3>

Выложенные для скачивания пакеты dvdisaster снабжены цифровой подписью с помощью
<a href="http://www.gnupg.org/gnupg.html">GnuPG</a>, поэтому вы можете проверить
целостность пакетов.<p>


Подпись была сделана с помощью следующего <a href="../pubkey.asc">открытого ключа</a>:

<pre>
pub   1024D/F5F6C46C 2003-08-22
      Key fingerprint = 12B3 1535 AF90 3ADE 9E73  BA7E 5A59 0EFE F5F6 C46C
uid                  dvdisaster (pkg signing key #1)
sub   1024g/091AD320 2003-08-22
</pre>

Пишите на <img src="../images/email.png" alt="email shown as png image" class="valigntt"> и вы получите
отпечаток ключа непосредственно от разработчиков. 
В тему письма вставьте строку "GPG finger print".

<h3>MD5 checksum</h3>

Contrary to the digital signature, MD5 checksums are cryptographically weak:
It is possible to create a manipulated package which still has the same
checksum as the original. However MD5 checksums are sufficient for a quick
check whether the download has finished completely and without transmission
errors.

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.79.3.orig.tar.bz2: dvdisaster-0.79.3/documentation/ru/download20.php <==
<?php
# dvdisaster: Russian homepage translation
# Copyright (C) 2007-2010 Igor Gorbounov
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<h3>Цифровая подпись</h3>

Выложенные для скачивания пакеты dvdisaster снабжены цифровой подписью с помощью
<a href="http://www.gnupg.org/gnupg.html">GnuPG</a>, поэтому вы можете проверить
целостность пакетов.<p>


Подпись была сделана с помощью следующего <a href="../pubkey.asc">открытого ключа</a>:

<a href="../pubkey.asc">
<pre>
pub   1024D/F5F6C46C 2003-08-22
      Key fingerprint = 12B3 1535 AF90 3ADE 9E73  BA7E 5A59 0EFE F5F6 C46C
uid                  dvdisaster (pkg signing key #1)
sub   1024g/091AD320 2003-08-22
</pre></a>

Пишите на <img src="../images/email.png" align="top"> и вы получите
отпечаток ключа непосредственно от разработчиков. 
В тему письма вставьте строку "GPG finger print".

<h3>MD5 checksum</h3>

Contrary to the digital signature, MD5 checksums are cryptographically weak:
It is possible to create a manipulated package which still has the same
checksum as the original. However MD5 checksums are sufficient for a quick
check whether the download has finished completely and without transmission
errors.

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
